==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Suorittimen tietoja ei ole saatavilla",
    "Load average" : "Keskiarvoinen kuorma",
    "Last minute" : "Viimeisin minuutti",
    "Memory info not available" : "Muistin tila ei saatavilla",
    "Total" : "Yhteensä",
    "Current usage" : "Tämänhetkinen kulutus",
    "Users" : "Käyttäjät",
    "Groups" : "Ryhmät",
    "Links" : "Linkit",
    "Mails" : "Sähköpostit",
    "Federated sent" : "Lähetetty federoituna",
    "Federated received" : "Vastaanotettu federoituna",
    "Talk conversations" : "Talk-keskustelut",
    "Last 24 hours" : "Viimeiset 24 tuntia",
    "Last 1 hour" : "Viimeisin tunti",
    "Last 5 mins" : "Viimeiset 5 min",
    "Copy" : "Kopioi",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Monitoring" : "Valvonta",
    "Monitoring app with useful server information" : "Valvontasovellus sisältäen hyödyllisiä tietoja palvelimesta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näyttää hyödyllisiä tietoja palvelimesta, kuten suorittimen kuorman, muistin ja levytilan käytön, käyttäjien määrän jne.",
    "CPU load" : "Suorittimen kuorma",
    "Memory usage" : "Muistin käyttö",
    "Active users" : "Aktiiviset käyttäjät",
    "Shares" : "Jaot",
    "Storage" : "Tallennustila",
    "Users:" : "Käyttäjiä:",
    "Files:" : "Tiedostoja:",
    "Storages:" : "Tallennustilat:",
    "Free Space:" : "Vapaata tilaa:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versio:",
    "Apps installed:" : "Sovelluksia asennettu:",
    "Apps updates available:" : "Sovelluspäivityksiä saatavilla:",
    "PHP" : "PHP",
    "Memory Limit:" : "Muistin raja:",
    "Max Execution Time:" : "Suurin suoritusaika:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "Size:" : "Koko:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "You can connect an external monitoring tool by using this end point:" : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa:",
    "Did you know?" : "Tiesitkö?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Lisäämällä \"?format=json\" URL-osoitteen loppuun saat tulokset JSON-muodossa!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Suorittimen tietoja ei ole saatavilla",
    "Load average" : "Keskiarvoinen kuorma",
    "Last minute" : "Viimeisin minuutti",
    "Memory info not available" : "Muistin tila ei saatavilla",
    "Total" : "Yhteensä",
    "Current usage" : "Tämänhetkinen kulutus",
    "Users" : "Käyttäjät",
    "Groups" : "Ryhmät",
    "Links" : "Linkit",
    "Mails" : "Sähköpostit",
    "Federated sent" : "Lähetetty federoituna",
    "Federated received" : "Vastaanotettu federoituna",
    "Talk conversations" : "Talk-keskustelut",
    "Copy" : "Kopioi",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Monitoring" : "Valvonta",
    "Monitoring app with useful server information" : "Valvontasovellus sisältäen hyödyllisiä tietoja palvelimesta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näyttää hyödyllisiä tietoja palvelimesta, kuten suorittimen kuorman, muistin ja levytilan käytön, käyttäjien määrän jne.",
    "Files:" : "Tiedostoja:",
    "Storages:" : "Tallennustilat:",
    "Free Space:" : "Vapaata tilaa:",
    "Active users" : "Aktiiviset käyttäjät",
    "Shares" : "Jaot",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory Limit:" : "Muistin raja:",
    "Max Execution Time:" : "Suurin suoritusaika:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "Size:" : "Koko:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "You can connect an external monitoring tool by using this end point:" : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa:",
    "Did you know?" : "Tiesitkö?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Lisäämällä \"?format=json\" URL-osoitteen loppuun saat tulokset JSON-muodossa!",
    "Last 24 hours" : "Viimeiset 24 tuntia",
    "Last 1 hour" : "Viimeisin tunti",
    "Last 5 mins" : "Viimeiset 5 min",
    "CPU load" : "Suorittimen kuorma",
    "Memory usage" : "Muistin käyttö",
    "Storage" : "Tallennustila",
    "Users:" : "Käyttäjiä:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Sovelluksia asennettu:",
    "Apps updates available:" : "Sovelluspäivityksiä saatavilla:"
},
"nplurals=2; plural=(n != 1);");
